.. _Grove git: https://github.com/hashicorp-forge/grove/
.. _templates: https://github.com/hashicorp-forge/grove/blob/main/templates

Examples
========

The following sections detail common configuration and deployment examples for Grove.

.. _deployment:

Deployment
----------

For up-to-date and production ready deployment examples, please see the `templates`_
directory inside the `Grove git`_ repository.

Configuration
-------------

For up-to-date and production ready configuration examples, please see the `templates`_
directory inside the `Grove git`_ repository.
